==> CGSocialApp-1.1.10.tar.gz: CGSocialApp/action.admin_savelocationsettings.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: CGSocialApp (c) 2012 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;
if( !$this->CheckPermission('Modify Site Preferences') ) return;

$this->SetCurrentTab('locationsettings');

if( isset($params['newlocation_notification_template_reset']) )
  {
    $txt = @file_get_contents(dirname(__FILE__).'/templates/orig_newlocation_notification_template.tpl');
    if( $txt )
      {
	$this->SetTemplate('newlocation_notification_template',$txt);
      }
  }
else if( isset($params['submit']) )
  {
    $this->SetPreference('newlocation_allow',(int)$params['newlocation_allow']);
    $this->SetPreference('newlocation_allowedit',(int)$params['newlocation_allowedit']);
    $this->SetPreference('newlocation_timelimit',(int)$params['newlocation_timelimit']);
    $this->SetPreference('newlocation_numlimit',(int)$params['newlocation_numlimit']);
    $this->SetPreference('newlocation_status',trim($params['newlocation_status']));
    $this->SetPreference('newlocation_notification_groups',trim($params['newlocation_notification_groups']));
    $this->SetPreference('newlocation_notification_subject',trim($params['newlocation_notification_subject']));
    $this->SetPreference('newlocation_notification_ishtml',trim($params['newlocation_notification_ishtml']));
    $this->SetTemplate('newlocation_notification_template',trim($params['newlocation_notification_template']));
  }

$this->RedirectToTab($id,'','','admin_settings');

#
# EOF
#
?>

==> CGSocialApp-1.3.1.tar.gz: CGSocialApp/action.admin_savelocationsettings.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: CGSocialApp (c) 2012 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;
if( !$this->CheckPermission('Modify Site Preferences') ) return;

$this->SetCurrentTab('locationsettings');

if( isset($params['newlocation_notification_template_reset']) ) {
  $txt = @file_get_contents(__DIR__.'/templates/orig_newlocation_notification_template.tpl');
  if( $txt ) $this->SetTemplate('newlocation_notification_template',$txt);
}
else if( isset($params['submit']) ) {
  $this->SetPreference('newlocation_allow',(int)$params['newlocation_allow']);
  $this->SetPreference('newlocation_allowedit',(int)$params['newlocation_allowedit']);
  $this->SetPreference('newlocation_timelimit',(int)$params['newlocation_timelimit']);
  $this->SetPreference('newlocation_numlimit',(int)$params['newlocation_numlimit']);
  $this->SetPreference('newlocation_status',trim($params['newlocation_status']));
  $this->SetPreference('newlocation_notification_groups',trim($params['newlocation_notification_groups']));
  $this->SetPreference('newlocation_notification_subject',trim($params['newlocation_notification_subject']));
  $this->SetPreference('newlocation_notification_ishtml',trim($params['newlocation_notification_ishtml']));
  $this->SetTemplate('newlocation_notification_template',trim($params['newlocation_notification_template']));
  $this->SetPreference('cd_ondelete_cleancheckins'(int)$params['cd_ondelete_cleancheckins']);
}

$this->RedirectToTab($id,'','','admin_settings');

#
# EOF
#
?>
